@@ -3,11 +3,11 @@
 
 #include "RobCovLibConfig.h"
 #include "armadillo"
-#include <omp.h>
+#include <Rcpp.h>
 
 namespace Utils
 {
- arma::mat runifsphere(size_t n, size_t p, int seed);
+ arma::mat runifsphere(size_t n, size_t p);
  arma::vec seq(const double& x, const double& y, const size_t& length);
  arma::rowvec mean(const arma::mat& X, int threads);
  arma::mat cov(const arma::mat& X, int threads);
